 <?php
 
# IwPopupManager - action.edit_popup.php
#
# Author : Infowebs - Musiscore
# Release : 0.2
#
# Release History
# Code Release		: 0.1		17-07-2025	- Initial Alpha Release
# Code Release		: 0.2		20-07-2025	- Added Pause field
# Code Release		: 0.3		24-07-2025	- Added Duration field
# Code Release		: 0.4		01-08-2025	- Added Style field
# -----------------------------------------------------------------------

 if( !defined('CMS_VERSION') ) exit;
 if( !$this->CheckPermission(IwPopupManager::MANAGE_PERM) ) return;
 $popup = new PopupItem();
 
if( isset($params['hid']) && $params['hid'] > 0) {
    $popup = PopupItem::load_by_id((int)$params['hid']);
 }
 
 if( isset($params['cancel']) ) {
    $this->RedirectToAdminTab();
 }
 else if( isset($params['submit']) ) {
    $popup->name = trim($params['name']);
    $popup->active = cms_to_bool($params['active']);
    $popup->content = $params['content'];
    $popup->description = $params['description'];
    $popup->pause = $params['pause'];
    $popup->duration = $params['duration'];
    $popup->style = $params['style'];
    $popup->save();
    $this->SetMessage($this->Lang('popup_saved'));
    $this->RedirectToAdminTab();
 }
 $tpl = $smarty->CreateTemplate($this->GetTemplateResource('edit_popup.tpl'),null,null, $smarty);
 $tpl->assign('popup',$popup);
 $tpl->display();
 ?>